summary refs log tree commit diff
path: root/tests
diff options
context:
space:
mode:
authorPatrick Cloke <clokep@users.noreply.github.com>2020-07-24 07:08:07 -0400
committerGitHub <noreply@github.com>2020-07-24 07:08:07 -0400
commit6a080ea184844f6ee9412a8d6170eb7ff2e5dd56 (patch)
tree33c4a914278d28a57f95180ee3c09a8e26375b34 /tests
parentDowngrade warning on client disconnect to INFO (#7928) (diff)
downloadsynapse-6a080ea184844f6ee9412a8d6170eb7ff2e5dd56.tar.xz
Return an empty body for OPTIONS requests. (#7886)
Diffstat (limited to 'tests')
-rw-r--r--tests/test_server.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/tests/test_server.py b/tests/test_server.py
index 42cada8964..073b2362cc 100644
--- a/tests/test_server.py
+++ b/tests/test_server.py
@@ -193,10 +193,10 @@ class OptionsResourceTests(unittest.TestCase):
         return channel
 
     def test_unknown_options_request(self):
         """An OPTIONS requests to an unknown URL still returns 200 OK."""
         channel = self._make_request(b"OPTIONS", b"/foo/")
-        self.assertEqual(channel.result["code"], b"200")
-        self.assertEqual(channel.result["body"], b"{}")
+        self.assertEqual(channel.result["code"], b"204")
+        self.assertNotIn("body", channel.result)
 
         # Ensure the correct CORS headers have been added
         self.assertTrue(
@@ -213,10 +213,10 @@ class OptionsResourceTests(unittest.TestCase):
         )
 
     def test_known_options_request(self):
         """An OPTIONS requests to an known URL still returns 200 OK."""
         channel = self._make_request(b"OPTIONS", b"/res/")
-        self.assertEqual(channel.result["code"], b"200")
-        self.assertEqual(channel.result["body"], b"{}")
+        self.assertEqual(channel.result["code"], b"204")
+        self.assertNotIn("body", channel.result)
 
         # Ensure the correct CORS headers have been added
         self.assertTrue(
@@ -193,10 +193,10 @@ class OptionsResourceTests(unittest.TestCase):
 
     def test_unknown_options_request(self):
-        """An OPTIONS requests to an unknown URL still returns 200 OK."""
+        """An OPTIONS requests to an unknown URL still returns 204 No Content."""
         channel = self._make_request(b"OPTIONS", b"/foo/")
@@ -213,10 +213,10 @@ class OptionsResourceTests(unittest.TestCase):
 
     def test_known_options_request(self):
-        """An OPTIONS requests to an known URL still returns 200 OK."""
+        """An OPTIONS requests to an known URL still returns 204 No Content."""
         channel = self._make_request(b"OPTIONS", b"/res/")